Inventory class

Constructors

Inventory({String? itemDescription, double? price, int? quantity})

Properties

hashCode int
The hash code for this object.
no setterinherited
itemDescription String?
getter/setter pair
price double?
getter/setter pair
quantity int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object message) Inventory